SCRIPT_TO_LANG = {
    'LATIN': 'en',
    'CYRILLIC': 'ru',
    'GREEK': 'el',
    'ARABIC': 'ar',
    'HEBREW': 'he',
    'DEVANAGARI': 'hi',
    'BENGALI': 'bn',
    'GUJARATI': 'gu',
    'GURMUKHI': 'pa',
    'TAMIL': 'ta',
    'TELUGU': 'te',
    'KANNADA': 'kn',
    'MALAYALAM': 'ml',
    'SINHALA': 'si',
    'THAI': 'th',
    'LAO': 'lo',
    'TIBETAN': 'bo',
    'MYANMAR': 'my',
    'GEORGIAN': 'ka',
    'HANGUL': 'ko',
    'HIRAGANA': 'ja',
    'KATAKANA': 'ja',
    'HAN': 'zh',
    'ARMENIAN': 'hy',
    'ETHIOPIC': 'am',
    'KHMER': 'km',
    'MONGOLIAN': 'mn',
    'CANADIAN': 'iu',
    'YI': 'ii',
    'CHEROKEE': 'chr',
    'THAANA': 'dv',
    'SYRIAC': 'syr',
    'SAMARITAN': 'sam',
    'MANDAIC': 'myz',
    'NKO': 'nqo',
    'TIFINAGH': 'ber',
    'OGHAM': 'sga',
    'RUNIC': 'non',
    'TAGALOG': 'tl',
    'HANUNOO': 'hnn',
    'BUHID': 'bku',
    'TAGBANWA': 'tbw',
    'LIMBU': 'lif',
    'TAI': 'tai',
    'BUGINESE': 'bug',
    'BALINESE': 'ban',
    'SUNDANESE': 'su',
    'LEPCHA': 'lep',
    'OL': 'sat',
    'JAVANESE': 'jv',
    'CHAM': 'cjm',
    'KAYAH': 'kyu',
    'REJANG': 'rej',
    'LYCIAN': 'xlc',
    'CARIAN': 'xcr',
    'LYDIAN': 'xld',
    'PHAGS-PA': 'xng',
    'PHOENICIAN': 'phn',
    'AVESTAN': 'ae',
    'IMPERIAL': 'xpr',
    'PARTHIAN': 'xpr',
    'PAHLAVI': 'pal',
    'PSALTER': 'pal',
    'OLD': 'xpr',
    'INSCRIPTIONAL': 'xpr',
    'BRAHMI': 'pra',
    'KAITHI': 'bh',
    'SORA': 'srb',
    'CHAKMA': 'ccp',
    'SHARADA': 'sa',
    'TAKRI': 'doi',
    'CUNEIFORM': 'akk',
    'EGYPTIAN': 'egy',
    'MEROITIC': 'xmr',
    'KHAROSHTHI': 'kho',
    'OSMANYA': 'so',
    'ELBASAN': 'sq',
    'CAUCASIAN': 'aqc',
    'LINEAR': 'grc',
    'CYPRIOT': 'grc',
    'PALMYRENE': 'arc',
    'NABATAEAN': 'arc',
    'HATRAN': 'arc',
    'PHOENICIAN': 'phn',
    'COPTIC': 'cop',
    'GOTHIC': 'got',
    'GLAGOLITIC': 'cu',
    'DESERET': 'en',
    'SHAVIAN': 'en',
    'OSMANYA': 'so',
    'TIFINAGH': 'ber',
    'BAMUM': 'bax',
    'VAI': 'vai',
    'MENDE': 'men',
}